import * as i0 from '@angular/core';
import { Injectable, inject, DestroyRef, PLATFORM_ID, Inject, viewChild, input, output, signal, computed, Component, ChangeDetectionStrategy, HostBinding, HostListener, provideExperimentalZonelessChangeDetection, NgModule } from '@angular/core';
import { switchMap, map, filter, debounceTime, shareReplay, startWith, mergeMap } from 'rxjs/operators';
import { wktToGeoJSON } from '@terraformer/wkt';
import { of, BehaviorSubject, Subject, tap, combineLatest, merge, firstValueFrom } from 'rxjs';
import * as i1 from '@angular/common/http';
import { provideHttpClient, withFetch } from '@angular/common/http';
import { takeUntilDestroyed, toObservable, toSignal } from '@angular/core/rxjs-interop';
import * as i3 from '@angular/forms';
import { FormControl, Validators, ReactiveFormsModule } from '@angular/forms';
import { isPlatformBrowser } from '@angular/common';

class GeocoderService {
    constructor(http) {
        this.http = http;
        this.geocoderBaseUrl = 'https://api.pdok.nl/bzk/locatieserver/search/v3_1';
    }
    suggest$(query, options) {
        let params = {
            q: query,
            fq: '*', // Also get percelen
            start: 0,
        };
        if (options) {
            params = Object.assign(params, options);
        }
        return this.http.get(`${this.geocoderBaseUrl}/suggest?`, { params: params })
            .pipe(switchMap(suggestResultObject => {
            if (suggestResultObject.spellcheck.collations.length > 0 && suggestResultObject.response.docs.length === 0) {
                return this.http.get(`${this.geocoderBaseUrl}/suggest?`, {
                    params: {
                        ...params,
                        q: suggestResultObject.spellcheck.collations[1].collationQuery
                    }
                }).pipe(map(newSuggestions => {
                    const places = this.formatPlaces(newSuggestions);
                    return { places };
                }));
            }
            const places = this.formatPlaces(suggestResultObject);
            return of({ places });
        }));
    }
    lookup$(id, options) {
        let params = {
            id: id,
            fl: '*'
        };
        if (options) {
            params = Object.assign(params, options);
        }
        return this.http.get(`${this.geocoderBaseUrl}/lookup?`, { params: params }).pipe(map(lookupResponse => this.formatLookupResponse(lookupResponse)));
    }
    free$(searchTerm, options) {
        let params = {
            q: searchTerm,
            fl: '*',
            fq: '*',
            rows: 10,
            start: 0,
        };
        if (options) {
            params = Object.assign(params, options);
        }
        return this.http.get(`${this.geocoderBaseUrl}/free?`, { params: params }).pipe(map(freeResponse => this.formatReverseResponse(freeResponse)));
    }
    reverse$(location, options) {
        let params = {
            fq: '*',
            fl: '*',
            rows: 10,
            distance: 200, // meter,
            lat: location.lat,
            lon: location.lon
        };
        if (options) {
            params = Object.assign(params, options);
        }
        const reverseUrl = `${this.geocoderBaseUrl}/reverse?`;
        return this.http.get(reverseUrl, { params: params }).pipe(map((reverseResponse) => this.formatReverseResponse(reverseResponse)));
    }
    formatPlaces(suggestResponse) {
        const places = suggestResponse.response.docs.map((place) => {
            return {
                ...place,
                highlight: suggestResponse.highlighting[place.id].suggest?.[0] || place.weergavenaam
            };
        });
        return places;
    }
    /**
     * Parse WKT in lookup response.
     */
    formatLookupResponse(lookupResponse) {
        const formatted = lookupResponse.response.docs.map((lookupResult) => {
            const formattedLookupResult = {
                ...lookupResult,
                ...(lookupResult.centroide_ll && { centroide_ll: wktToGeoJSON(lookupResult.centroide_ll) }),
                ...(lookupResult.centroide_rd && { centroide_rd: wktToGeoJSON(lookupResult.centroide_rd) }),
                ...(lookupResult.geometrie_rd && { geometrie_rd: wktToGeoJSON(lookupResult.geometrie_rd) }),
                ...(lookupResult.geometrie_ll && { geometrie_ll: wktToGeoJSON(lookupResult.geometrie_ll) }),
                highlight: lookupResult.weergavenaam,
            };
            return formattedLookupResult;
        });
        return formatted[0] || null;
    }
    formatReverseResponse(lookupResultObject) {
        const formatted = lookupResultObject.response.docs.map((reverseResult) => {
            const formattedLookupResult = {
                ...reverseResult,
                ...(reverseResult.centroide_ll && { centroide_ll: wktToGeoJSON(reverseResult.centroide_ll) }),
                ...(reverseResult.centroide_rd && { centroide_rd: wktToGeoJSON(reverseResult.centroide_rd) }),
                ...(reverseResult.geometrie_rd && { geometrie_rd: wktToGeoJSON(reverseResult.geometrie_rd) }),
                ...(reverseResult.geometrie_ll && { geometrie_ll: wktToGeoJSON(reverseResult.geometrie_ll) }),
                highlight: reverseResult.weergavenaam,
            };
            return formattedLookupResult;
        });
        return formatted;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: GeocoderService, deps: [{ token: i1.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: GeocoderService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: GeocoderService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: i1.HttpClient }] });

class GeocoderHistoryService {
    constructor(platformId) {
        this.platformId = platformId;
        this.MAX_HISTORY_ENTRIES = 5;
        this.HISTORY_LOCALSTORAGE_KEY = 'geocoder_history_v1';
        this.history$ = new BehaviorSubject(this.retrieveHistory());
        this.destroyRef = inject(DestroyRef);
        this.saveToLocalStorage = this.history$.pipe(takeUntilDestroyed(this.destroyRef)).subscribe(history => {
            this.saveHistory(history);
        });
    }
    getHistory() {
        return this.history$.value;
    }
    updateHistory(lookupObject) {
        const existingIndex = this.history$.value.findIndex(h => h.id === lookupObject.id);
        if (existingIndex === -1) {
            this.history$.next([...this.history$.value, lookupObject].slice(-this.MAX_HISTORY_ENTRIES));
        }
        // Don't add a duplicate search result, but instead move it to end of array
        const updatedHistory = [...this.history$.value];
        updatedHistory.splice(existingIndex, 1);
        updatedHistory.push(lookupObject);
        this.history$.next(updatedHistory);
    }
    saveHistory(history) {
        if (!this.isLocalStorageAvailable()) {
            return;
        }
        localStorage.setItem(this.HISTORY_LOCALSTORAGE_KEY, JSON.stringify(history));
    }
    retrieveHistory() {
        if (!this.isLocalStorageAvailable()) {
            return [];
        }
        const history = localStorage.getItem(this.HISTORY_LOCALSTORAGE_KEY);
        try {
            return JSON.parse(history) || [];
        }
        catch (e) {
            console.error('Error parsing history from localStorage', e);
            return [];
        }
    }
    isLocalStorageAvailable() {
        if (isPlatformBrowser(this.platformId)) {
            return true;
        }
        return false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: GeocoderHistoryService, deps: [{ token: PLATFORM_ID }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: GeocoderHistoryService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: GeocoderHistoryService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [PLATFORM_ID]
                }] }] });

class GeocoderComponent {
    get hostGeocoderClass() {
        return this.hasFocus();
    }
    clickout(event) {
        if (this.geocoderRef().nativeElement.contains(event.target)) {
            this.showSuggestions();
        }
        else {
            this.hideResults();
        }
    }
    constructor(geocoderService, geocoderHistoryService) {
        this.geocoderService = geocoderService;
        this.geocoderHistoryService = geocoderHistoryService;
        this.SEARCH_CHARACTER_THRESHOLD = 2;
        this.geocoderRef = viewChild('geocoder');
        this.type = input(undefined);
        this.searchInput = input(undefined);
        this.placeholder = input(undefined);
        this.resultCountLimit = input(12);
        this.province = input(undefined);
        this.fullscreen = input(false);
        this.microphone = input(true);
        this.boxshadow = input(true);
        this.borderradius = input(true);
        this.placeFound = output();
        this.clearResults = output();
        this.query = output();
        this.freeSearchResults = output();
        this.blur = output();
        this.hasFocus = signal(false);
        this.formattedPlaceholder = computed(() => this.formatPlaceholder(this.placeholder()));
        // Microphone
        this.searchControl = new FormControl(undefined, { validators: [Validators.minLength(this.SEARCH_CHARACTER_THRESHOLD)] });
        this.microphoneActive = signal(false);
        // Reverse geocoding
        this.userGpsLocation$ = new Subject();
        this.suggest$ = this.searchControl.valueChanges.pipe(filter(searchInput => searchInput.length > this.SEARCH_CHARACTER_THRESHOLD), debounceTime(200), tap((input) => this.query.emit(input)), switchMap(searchInput => this.suggest(searchInput)), shareReplay());
        this.reverseSuggest$ = this.userGpsLocation$.pipe(switchMap((params) => this.reverse(params)), shareReplay());
        this.useMyLocationPlace = {
            weergavenaam: 'Gebruik huidige locatie',
            subtitle: 'Zoek met GPS/apparaatlocatie',
            type: 'gps',
            id: 'gps'
        };
        this.historyWithTypeFilter$ = combineLatest([this.geocoderHistoryService.history$, toObservable(this.type)]).pipe(map(([history, type]) => {
            if (type === undefined || type === null || type.length === 0) {
                return history;
            }
            const allTypes = type.split(',');
            return history.filter(h => allTypes.includes(h.type));
        }));
        this.tooFewCharacters$ = this.searchControl.valueChanges.pipe(startWith(this.searchControl.value), filter(searchInput => searchInput?.length <= this.SEARCH_CHARACTER_THRESHOLD || searchInput === null), mergeMap(() => this.historyWithTypeFilter$), map(history => [...history.slice().reverse(), this.useMyLocationPlace]));
        this.places$ = merge(this.suggest$.pipe(map((response) => response.places)), this.reverseSuggest$, this.tooFewCharacters$);
        this.places = toSignal(this.places$);
        this.foundPlace$ = new BehaviorSubject(null);
        this.selectedIndex = -1;
        this.lookupResponseFound = signal(false);
        this.reachedThreshold$ = this.searchControl.valueChanges.pipe(startWith(''), map(val => (val && val.length) > this.SEARCH_CHARACTER_THRESHOLD));
        this.noPlacesFound$ = this.places$.pipe(map(places => places.length === 0));
        this.noResult$ = this.foundPlace$.pipe(map(place => place === null));
        this.noResult = toSignal(this.noResult$);
        this.isNoResultsFound = toSignal(combineLatest([this.reachedThreshold$, this.noPlacesFound$, this.noResult$]).pipe(map(([reachedThreshold, noSuggestions, noResult]) => reachedThreshold && noSuggestions && noResult)));
    }
    ngOnInit() {
    }
    ngOnChanges(changes) {
        if (changes.searchInput) {
            this.searchControl.setValue(changes.searchInput.currentValue);
        }
    }
    suggest(searchTerm) {
        const flArray = ['id', 'score', 'type', 'weergavenaam', 'straatnaam', 'huis_nlt', 'woonplaatsnaam', 'kadastrale_gemeentecode', 'kadastrale_sectie', 'perceelnummer', 'kadastrale_gemeentenaam'];
        const params = {
            fq: '*:*',
            fl: flArray.toString(),
            rows: this.resultCountLimit()
        };
        const formattedSearchTerm = this.formatSearchTerm(searchTerm);
        const type = this.type();
        const provinceValue = this.province();
        if (type) {
            const replace = ',';
            const regex = new RegExp(replace, 'g');
            const query = type.replace(regex, ' OR ');
            params.fq = `type:(${query})`;
            const province = this.province();
            if (province) {
                params.fq += ` AND provincienaam:(${province})`;
            }
        }
        else if (provinceValue) {
            params.fq = `provincienaam:(${provinceValue})`;
        }
        return this.geocoderService.suggest$(formattedSearchTerm, params);
    }
    reverse(params) {
        const opts = {
            type: 'adres',
            fq: '*:*',
            rows: this.resultCountLimit()
        };
        const type = this.type();
        const provinceValue = this.province();
        if (type) {
            // Set type to all and use FQ to determine type, so that we can re-use logic
            opts.type = '*';
            const replace = ',';
            const regex = new RegExp(replace, 'g');
            const query = type.replace(regex, ' OR ');
            opts.fq = `type:(${query})`;
            const province = this.province();
            if (province) {
                opts.fq += ` AND provincienaam:(${province})`;
            }
        }
        else if (provinceValue) {
            opts.fq = `provincienaam:(${provinceValue})`;
        }
        return this.geocoderService.reverse$(params, opts);
    }
    async lookup(id) {
        const lookupObj = await this.geocoderService.lookup$(id).toPromise();
        this.foundPlace$.next(lookupObj);
        this.geocoderHistoryService.updateHistory(lookupObj);
        this.fillInput(lookupObj.weergavenaam);
        this.placeFound.emit(lookupObj);
        this.lookupResponseFound.set(true);
        this.clearPlaces();
        this.hideResults();
    }
    async reverseGeocode() {
        const gpsLocation = await this.getGpsLocation();
        this.userGpsLocation$.next(gpsLocation);
    }
    async free() {
        const params = {
            fq: '*:*',
            rows: this.resultCountLimit()
        };
        const type = this.type();
        const provinceValue = this.province();
        if (type) {
            const replace = ',';
            const regex = new RegExp(replace, 'g');
            const query = type.replace(regex, ' OR ');
            params.fq = `type:(${query})`;
            const province = this.province();
            if (province) {
                params.fq += ` AND provincienaam:(${province})`;
            }
        }
        else if (provinceValue) {
            params.fq = `provincienaam:(${provinceValue})`;
        }
        const searchTerm = this.searchControl.value;
        const free = await firstValueFrom(this.geocoderService.free$(searchTerm, params));
        this.freeSearchResults.emit(free);
    }
    clear(event) {
        event.preventDefault();
        event.stopPropagation();
        this.foundPlace$.next(null);
        this.searchControl.setValue('');
        this.clearPlaces();
        this.lookupResponseFound.set(false);
        this.hideResults();
        this.clearResults.emit(true);
    }
    clearPlaces() {
        this.resetIndex();
    }
    async handleSuggestClick(id) {
        if (id === 'gps') {
            this.reverseGeocode();
        }
        else {
            this.lookup(id);
        }
    }
    handleEnter(places) {
        if (this.selectedIndex === -1) {
            return;
        }
        const selectedPlace = places[this.selectedIndex];
        this.lookup(selectedPlace.id);
    }
    fillInput(content, emitEvent = false) {
        this.searchControl.setValue(content, {
            emitEvent: emitEvent
        });
    }
    isHighlighted(i) {
        if (i === this.selectedIndex) {
            return true;
        }
    }
    moveUp() {
        if (this.selectedIndex > 0) {
            this.selectedIndex--;
        }
    }
    moveDown(places) {
        if (this.selectedIndex < places.length) {
            this.selectedIndex++;
        }
    }
    resetIndex() {
        this.selectedIndex = -1;
    }
    canQuery() {
        const searchInput = this.searchControl.value;
        return searchInput && searchInput.length > this.SEARCH_CHARACTER_THRESHOLD;
    }
    canClear() {
        const searchInput = this.searchControl.value;
        return searchInput && searchInput.length > 0;
    }
    formatPlaceholder(placeholder) {
        let placeholderText = 'Zoeken op de kaart...';
        if (placeholder) {
            placeholderText = placeholder;
        }
        return placeholderText;
    }
    showSuggestions() {
        this.hasFocus.set(true);
    }
    getSpeechRecognition() {
        if (this.speechRecognizer) {
            return this.speechRecognizer;
        }
        //@ts-ignore
        const SpeechRecognition = window.SpeechRecognition || window.webkitSpeechRecognition;
        const recognition = new SpeechRecognition();
        recognition.interimResults = false; // Set to true if you want interim results
        recognition.lang = 'nl-NL'; // Set the language here
        this.speechRecognizer = recognition;
        return this.speechRecognizer;
    }
    speechToText(event) {
        const recognition = this.getSpeechRecognition();
        if (this.microphoneActive() === true) {
            return recognition.stop();
        }
        recognition.onresult = (event) => {
            this.searchControl.setValue(event.results[0][0]?.transcript);
        };
        recognition.onend = (event) => {
            this.microphoneActive.set(false);
        };
        this.microphoneActive.set(true);
        recognition.start();
    }
    hideResults() {
        this.hasFocus.set(false);
    }
    async getGpsLocation() {
        if (!navigator.geolocation) {
            alert('GPS wordt niet ondersteund door uw apparaat');
            return null;
        }
        return new Promise((resolve, reject) => {
            navigator.geolocation.getCurrentPosition((position) => {
                resolve({
                    lat: position.coords.latitude,
                    lon: position.coords.longitude
                });
            }, (error) => {
                const map = {
                    1: 'U heeft ons geen toestemming gegeven om uw locatie op te halen',
                    2: 'Uw locatie is niet beschikbaar',
                    3: 'Het duurt te lang om uw locatie op te halen'
                };
                alert(map[error.code] || 'Het is niet gelukt om uw locatie op te halen');
                reject(error);
            });
        });
    }
    formatSearchTerm(searchTerm) {
        const isKadastraleAanduidingRegex = /[a-zA-Z]{3}[0-9]{2}[a-zA-Z]{1,2}[0-9]{1,5}/;
        const isBagId = /^\d{16}$/;
        if (isKadastraleAanduidingRegex.test(searchTerm) === true) {
            // Use three capturing groups () () () to split the string by.
            const splitAanduidingRegex = /([a-zA-Z]{3}[0-9]{2})([a-zA-Z]{1,2})([0-9]{1,5})/;
            const formattedTerm = searchTerm.split(splitAanduidingRegex).filter(str => str !== '').join(' ');
            return formattedTerm;
        }
        if (isBagId.test(searchTerm) === true) {
            return `* AND (adresseerbaarobject_id:${searchTerm} OR nummeraanduiding_id:${searchTerm})`;
        }
        return searchTerm;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: GeocoderComponent, deps: [{ token: GeocoderService }, { token: GeocoderHistoryService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.0.3", type: GeocoderComponent, isStandalone: false, selector: "angular-geocoder", inputs: { type: { classPropertyName: "type", publicName: "type", isSignal: true, isRequired: false, transformFunction: null }, searchInput: { classPropertyName: "searchInput", publicName: "searchInput", isSignal: true, isRequired: false, transformFunction: null }, placeholder: { classPropertyName: "placeholder", publicName: "placeholder", isSignal: true, isRequired: false, transformFunction: null }, resultCountLimit: { classPropertyName: "resultCountLimit", publicName: "resultCountLimit", isSignal: true, isRequired: false, transformFunction: null }, province: { classPropertyName: "province", publicName: "province", isSignal: true, isRequired: false, transformFunction: null }, fullscreen: { classPropertyName: "fullscreen", publicName: "fullscreen", isSignal: true, isRequired: false, transformFunction: null }, microphone: { classPropertyName: "microphone", publicName: "microphone", isSignal: true, isRequired: false, transformFunction: null }, boxshadow: { classPropertyName: "boxshadow", publicName: "boxshadow", isSignal: true, isRequired: false, transformFunction: null }, borderradius: { classPropertyName: "borderradius", publicName: "borderradius", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { placeFound: "placeFound", clearResults: "clearResults", query: "query", freeSearchResults: "freeSearchResults", blur: "blur" }, host: { listeners: { "document:click": "clickout($event)" }, properties: { "class.geocoder--selected": "this.hostGeocoderClass" }, classAttribute: "geocoder" }, viewQueries: [{ propertyName: "geocoderRef", first: true, predicate: ["geocoder"], descendants: true, isSignal: true }], usesOnChanges: true, ngImport: i0, template: "<div #geocoder (keydown.ArrowUp)=\"moveUp()\" (keydown.ArrowDown)=\"moveDown(places())\"\r\n  (keydown.Enter)=\"handleEnter(places())\" class=\"geocoder-container\"\r\n  [class.geocoder-container--fullscreen]=\"hasFocus() === true && fullscreen() === true\" [class.boxshadow]=\"boxshadow()\"\r\n  [class.borderradius]=\"borderradius()\">\r\n  <!-- Input -->\r\n  <div class=\"geocoder-search\">\r\n    @if (hasFocus() && fullscreen() === true) {\r\n    <button aria-label=\"Terug\" class=\"back\" (click)=\"clear($event)\">\r\n      <svg viewBox=\"0 0 768 768\" height=\"21\" width=\"21\" fill=\"currentColor\">\r\n        <path\r\n          d=\"M406.624 585.376l-169.376-169.376h370.752c17.664 0 32-14.336 32-32s-14.336-32-32-32h-370.752l169.376-169.376c12.512-12.512 12.512-32.768 0-45.248s-32.768-12.512-45.248 0l-224 224c-3.072 3.072-5.376 6.592-6.944 10.368-1.632 3.904-2.432 8.096-2.432 12.256 0 8.192 3.136 16.384 9.376 22.624l224 224c12.512 12.512 32.768 12.512 45.248 0s12.512-32.768 0-45.248z\">\r\n        </path>\r\n      </svg>\r\n    </button>\r\n    }\r\n\r\n    <input (click)=\"showSuggestions()\" [formControl]=\"searchControl\" (blur)=\"blur.emit($event)\"\r\n      class=\"geocoder-search__input\" [placeholder]=\"formattedPlaceholder()\" type=\"text\" maxlength=\"100\">\r\n\r\n    @if (microphone() === true) {\r\n    <button (click)=\"speechToText($event)\" aria-label=\"Zoeken met spraak\" class=\"mic\"\r\n      [class.mic--active]=\"microphoneActive()\">\r\n      <svg xmlns=\"http://www.w3.org/2000/svg\" width=\"17\" height=\"17\" viewBox=\"0 0 24 24\" fill=\"none\"\r\n        stroke=\"currentColor\" stroke-width=\"2\" stroke-linecap=\"round\" stroke-linejoin=\"round\">\r\n        <path d=\"M12 1a3 3 0 0 0-3 3v8a3 3 0 0 0 6 0V4a3 3 0 0 0-3-3z\"></path>\r\n        <path d=\"M19 10v2a7 7 0 0 1-14 0v-2\"></path>\r\n        <line x1=\"12\" y1=\"19\" x2=\"12\" y2=\"23\"></line>\r\n        <line x1=\"8\" y1=\"23\" x2=\"16\" y2=\"23\"></line>\r\n      </svg>\r\n    </button>\r\n    }\r\n\r\n\r\n    @if (lookupResponseFound() === true) {\r\n    <button aria-label=\"Sluiten\" class=\"close\" width=\"15\" height=\"15\" (click)=\"clear($event)\">\r\n      <svg viewBox=\"0 0 384 512\">\r\n        <path fill=\"currentColor\"\r\n          d=\"M217.5 256l137.2-137.2c4.7-4.7 4.7-12.3 0-17l-8.5-8.5c-4.7-4.7-12.3-4.7-17 0L192 230.5 54.8 93.4c-4.7-4.7-12.3-4.7-17 0l-8.5 8.5c-4.7 4.7-4.7 12.3 0 17L166.5 256 29.4 393.2c-4.7 4.7-4.7 12.3 0 17l8.5 8.5c4.7 4.7 12.3 4.7 17 0L192 281.5l137.2 137.2c4.7 4.7 12.3 4.7 17 0l8.5-8.5c4.7-4.7 4.7-12.3 0-17L217.5 256z\"\r\n          class=\"\"></path>\r\n      </svg>\r\n    </button>\r\n    } @else {\r\n    <button (click)=\"free()\" aria-label=\"Zoeken met tekst\" class=\"search\">\r\n      <svg xmlns=\"http://www.w3.org/2000/svg\" width=\"18\" height=\"18\" viewBox=\"0 0 24 24\" fill=\"none\"\r\n        stroke=\"currentColor\" stroke-width=\"2\" stroke-linecap=\"round\" stroke-linejoin=\"round\">\r\n        <circle cx=\"11\" cy=\"11\" r=\"8\"></circle>\r\n        <line x1=\"21\" y1=\"21\" x2=\"16.65\" y2=\"16.65\"></line>\r\n      </svg>\r\n    </button>\r\n    }\r\n\r\n  </div>\r\n\r\n\r\n  <!-- Search results-->\r\n  @if (hasFocus() === true) {\r\n  @if (places().length > 0) {\r\n  <div class=\"geocoder-suggestions\">\r\n    <ul class=\"geocoder-suggestions__list\">\r\n      @for (place of places(); track place.id; let i = $index) {\r\n      <li class=\"geocoder-suggestion\" tabindex={{i}} (click)=\"handleSuggestClick(place.id)\"\r\n        [class.geocoder-suggestion--focus]=\"isHighlighted(i)\">\r\n\r\n        @switch (place.type) {\r\n        @case ('gps') {\r\n        <div class=\"geocoder-suggestion__content\">\r\n          <div class=\"geocoder-suggestion__content__title\">\r\n            {{ place.weergavenaam }}\r\n          </div>\r\n          <div class=\"geocoder-suggestion__content__subtitle\"> {{place.subtitle}}</div>\r\n        </div>\r\n        }\r\n\r\n        @case ('adres') {\r\n        <div class=\"geocoder-suggestion__content\">\r\n          <div class=\"geocoder-suggestion__content__title\">\r\n            {{place.straatnaam }} {{place.huis_nlt}}\r\n          </div>\r\n          <div class=\"geocoder-suggestion__content__subtitle\"> {{place.woonplaatsnaam}}</div>\r\n        </div>\r\n        }\r\n\r\n        @case ('perceel') {\r\n        <div class=\"geocoder-suggestion__content\">\r\n          <div class=\"geocoder-suggestion__content__title\">\r\n            Perceel {{place.kadastrale_gemeentecode }} {{place.kadastrale_sectie}} {{place.perceelnummer}}\r\n          </div>\r\n          <div class=\"geocoder-suggestion__content__subtitle\"> {{place.kadastrale_gemeentenaam}}</div>\r\n        </div>\r\n        }\r\n\r\n        @case ('weg') {\r\n        <div class=\"geocoder-suggestion__content\">\r\n          <div class=\"geocoder-suggestion__content__title\">\r\n            {{place.straatnaam }}\r\n          </div>\r\n          <div class=\"geocoder-suggestion__content__subtitle\"> {{place.woonplaatsnaam}}</div>\r\n        </div>\r\n        }\r\n\r\n        @default {\r\n        <div class=\"geocoder-suggestion__content\">\r\n          <div class=\"geocoder-suggestion__content__title\" [innerHTML]=\"place.highlight\">\r\n          </div>\r\n        </div>\r\n        }\r\n\r\n        }\r\n        <div class=\"geocoder-suggestion__type\"> {{place.type}} </div>\r\n\r\n      </li>\r\n      }\r\n\r\n    </ul>\r\n  </div>\r\n  }\r\n\r\n  @if (isNoResultsFound() === true) {\r\n  <div class=\"geocoder-noresults\">\r\n    Geen resultaten voor <strong>\"{{searchControl.value}}\"</strong>\r\n  </div>\r\n  }\r\n\r\n  <!-- Backdrop-->\r\n  @if (fullscreen() === true) {\r\n  <div class=\"geocoder-backdrop\"></div>\r\n  }\r\n  }\r\n</div>", styles: ["*:focus{outline:0}::placeholder{color:#797979}.geocoder-container{position:relative;width:100%;height:100%;max-width:100%;overscroll-behavior-y:none;line-height:19px;font-size:13px;color:#444}.geocoder-container--fullscreen{position:fixed;top:0;right:0;left:0;height:100vh;height:100dvh}.geocoder-search{position:relative;display:flex;align-items:center;width:100%;z-index:1;background:#fff;box-sizing:border-box;border:1px solid #eee}.geocoder-search__input{flex:1 1 auto;margin:0;padding:14px 15px;max-width:calc(100% - 70px);overflow:hidden;text-overflow:ellipsis;border-radius:15px;border:none}button{display:flex;align-items:center;padding:0 15px;cursor:pointer;background:#fff;border:none}button.close{position:absolute;right:0}button.mic{padding:0 8px 0 0}button.back{padding-right:0}svg{width:18px;height:auto;color:#797979}button.back svg{width:21px}button.mic svg{width:17px}button.close svg{width:15px}button:hover svg{color:#008cba}button.mic--active svg{animation:pulse 1s infinite}@keyframes pulse{0%{color:#797979}50%{color:#3498db}to{color:#797979}}.geocoder-suggestions{position:relative;width:100%;z-index:2;max-height:calc(100% - 49px);overflow-y:auto;overscroll-behavior-y:none;border:1px solid #eee;border-width:0 1px 1px;background:#fff}.geocoder-suggestions__list{margin:0;padding:0;list-style-type:none}.geocoder-suggestion{display:flex;gap:5px;align-items:center;margin:0;padding:12px 15px;border-bottom:1px solid #eee;cursor:pointer}.geocoder-suggestion:last-of-type{border-bottom:none}.geocoder-suggestion:hover,.geocoder-suggestion--focus{background-color:#f7f7f7}.geocoder-suggestion__content{margin-right:10px}.geocoder-suggestion__content__subtitle{color:#838383}.geocoder-suggestion__type{margin:0 0 0 auto;font-size:11px;font-weight:700;text-transform:uppercase;color:#bfbfbf}.geocoder-noresults{position:relative;width:100%;padding:18px 15px;z-index:1;background:#fff;border:1px solid #eee;border-width:0 1px 1px;box-sizing:border-box}.geocoder-backdrop{position:fixed;inset:0;height:100%;width:100%;z-index:0;background:#f5f5f5}.borderradius .geocoder-search,.borderradius .geocoder-search__input{border-radius:0 0 15px 15px}@media (min-width: 787px){.borderradius .geocoder-search,.borderradius .geocoder-search__input{border-radius:15px}}.borderradius button,.borderradius .geocoder-suggestions,.borderradius .geocoder-noresults{border-radius:15px}.boxshadow .geocoder-search,.boxshadow .geocoder-suggestions,.boxshadow .geocoder-noresults{box-shadow:0 2px 4px #0003,0 -1px #00000005;border:none}\n"], dependencies: [{ kind: "directive", type: i3.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i3.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i3.MaxLengthValidator, selector: "[maxlength][formControlName],[maxlength][formControl],[maxlength][ngModel]", inputs: ["maxlength"] }, { kind: "directive", type: i3.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: GeocoderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'angular-geocoder', host: { 'class': 'geocoder' }, changeDetection: ChangeDetectionStrategy.OnPush, standalone: false, template: "<div #geocoder (keydown.ArrowUp)=\"moveUp()\" (keydown.ArrowDown)=\"moveDown(places())\"\r\n  (keydown.Enter)=\"handleEnter(places())\" class=\"geocoder-container\"\r\n  [class.geocoder-container--fullscreen]=\"hasFocus() === true && fullscreen() === true\" [class.boxshadow]=\"boxshadow()\"\r\n  [class.borderradius]=\"borderradius()\">\r\n  <!-- Input -->\r\n  <div class=\"geocoder-search\">\r\n    @if (hasFocus() && fullscreen() === true) {\r\n    <button aria-label=\"Terug\" class=\"back\" (click)=\"clear($event)\">\r\n      <svg viewBox=\"0 0 768 768\" height=\"21\" width=\"21\" fill=\"currentColor\">\r\n        <path\r\n          d=\"M406.624 585.376l-169.376-169.376h370.752c17.664 0 32-14.336 32-32s-14.336-32-32-32h-370.752l169.376-169.376c12.512-12.512 12.512-32.768 0-45.248s-32.768-12.512-45.248 0l-224 224c-3.072 3.072-5.376 6.592-6.944 10.368-1.632 3.904-2.432 8.096-2.432 12.256 0 8.192 3.136 16.384 9.376 22.624l224 224c12.512 12.512 32.768 12.512 45.248 0s12.512-32.768 0-45.248z\">\r\n        </path>\r\n      </svg>\r\n    </button>\r\n    }\r\n\r\n    <input (click)=\"showSuggestions()\" [formControl]=\"searchControl\" (blur)=\"blur.emit($event)\"\r\n      class=\"geocoder-search__input\" [placeholder]=\"formattedPlaceholder()\" type=\"text\" maxlength=\"100\">\r\n\r\n    @if (microphone() === true) {\r\n    <button (click)=\"speechToText($event)\" aria-label=\"Zoeken met spraak\" class=\"mic\"\r\n      [class.mic--active]=\"microphoneActive()\">\r\n      <svg xmlns=\"http://www.w3.org/2000/svg\" width=\"17\" height=\"17\" viewBox=\"0 0 24 24\" fill=\"none\"\r\n        stroke=\"currentColor\" stroke-width=\"2\" stroke-linecap=\"round\" stroke-linejoin=\"round\">\r\n        <path d=\"M12 1a3 3 0 0 0-3 3v8a3 3 0 0 0 6 0V4a3 3 0 0 0-3-3z\"></path>\r\n        <path d=\"M19 10v2a7 7 0 0 1-14 0v-2\"></path>\r\n        <line x1=\"12\" y1=\"19\" x2=\"12\" y2=\"23\"></line>\r\n        <line x1=\"8\" y1=\"23\" x2=\"16\" y2=\"23\"></line>\r\n      </svg>\r\n    </button>\r\n    }\r\n\r\n\r\n    @if (lookupResponseFound() === true) {\r\n    <button aria-label=\"Sluiten\" class=\"close\" width=\"15\" height=\"15\" (click)=\"clear($event)\">\r\n      <svg viewBox=\"0 0 384 512\">\r\n        <path fill=\"currentColor\"\r\n          d=\"M217.5 256l137.2-137.2c4.7-4.7 4.7-12.3 0-17l-8.5-8.5c-4.7-4.7-12.3-4.7-17 0L192 230.5 54.8 93.4c-4.7-4.7-12.3-4.7-17 0l-8.5 8.5c-4.7 4.7-4.7 12.3 0 17L166.5 256 29.4 393.2c-4.7 4.7-4.7 12.3 0 17l8.5 8.5c4.7 4.7 12.3 4.7 17 0L192 281.5l137.2 137.2c4.7 4.7 12.3 4.7 17 0l8.5-8.5c4.7-4.7 4.7-12.3 0-17L217.5 256z\"\r\n          class=\"\"></path>\r\n      </svg>\r\n    </button>\r\n    } @else {\r\n    <button (click)=\"free()\" aria-label=\"Zoeken met tekst\" class=\"search\">\r\n      <svg xmlns=\"http://www.w3.org/2000/svg\" width=\"18\" height=\"18\" viewBox=\"0 0 24 24\" fill=\"none\"\r\n        stroke=\"currentColor\" stroke-width=\"2\" stroke-linecap=\"round\" stroke-linejoin=\"round\">\r\n        <circle cx=\"11\" cy=\"11\" r=\"8\"></circle>\r\n        <line x1=\"21\" y1=\"21\" x2=\"16.65\" y2=\"16.65\"></line>\r\n      </svg>\r\n    </button>\r\n    }\r\n\r\n  </div>\r\n\r\n\r\n  <!-- Search results-->\r\n  @if (hasFocus() === true) {\r\n  @if (places().length > 0) {\r\n  <div class=\"geocoder-suggestions\">\r\n    <ul class=\"geocoder-suggestions__list\">\r\n      @for (place of places(); track place.id; let i = $index) {\r\n      <li class=\"geocoder-suggestion\" tabindex={{i}} (click)=\"handleSuggestClick(place.id)\"\r\n        [class.geocoder-suggestion--focus]=\"isHighlighted(i)\">\r\n\r\n        @switch (place.type) {\r\n        @case ('gps') {\r\n        <div class=\"geocoder-suggestion__content\">\r\n          <div class=\"geocoder-suggestion__content__title\">\r\n            {{ place.weergavenaam }}\r\n          </div>\r\n          <div class=\"geocoder-suggestion__content__subtitle\"> {{place.subtitle}}</div>\r\n        </div>\r\n        }\r\n\r\n        @case ('adres') {\r\n        <div class=\"geocoder-suggestion__content\">\r\n          <div class=\"geocoder-suggestion__content__title\">\r\n            {{place.straatnaam }} {{place.huis_nlt}}\r\n          </div>\r\n          <div class=\"geocoder-suggestion__content__subtitle\"> {{place.woonplaatsnaam}}</div>\r\n        </div>\r\n        }\r\n\r\n        @case ('perceel') {\r\n        <div class=\"geocoder-suggestion__content\">\r\n          <div class=\"geocoder-suggestion__content__title\">\r\n            Perceel {{place.kadastrale_gemeentecode }} {{place.kadastrale_sectie}} {{place.perceelnummer}}\r\n          </div>\r\n          <div class=\"geocoder-suggestion__content__subtitle\"> {{place.kadastrale_gemeentenaam}}</div>\r\n        </div>\r\n        }\r\n\r\n        @case ('weg') {\r\n        <div class=\"geocoder-suggestion__content\">\r\n          <div class=\"geocoder-suggestion__content__title\">\r\n            {{place.straatnaam }}\r\n          </div>\r\n          <div class=\"geocoder-suggestion__content__subtitle\"> {{place.woonplaatsnaam}}</div>\r\n        </div>\r\n        }\r\n\r\n        @default {\r\n        <div class=\"geocoder-suggestion__content\">\r\n          <div class=\"geocoder-suggestion__content__title\" [innerHTML]=\"place.highlight\">\r\n          </div>\r\n        </div>\r\n        }\r\n\r\n        }\r\n        <div class=\"geocoder-suggestion__type\"> {{place.type}} </div>\r\n\r\n      </li>\r\n      }\r\n\r\n    </ul>\r\n  </div>\r\n  }\r\n\r\n  @if (isNoResultsFound() === true) {\r\n  <div class=\"geocoder-noresults\">\r\n    Geen resultaten voor <strong>\"{{searchControl.value}}\"</strong>\r\n  </div>\r\n  }\r\n\r\n  <!-- Backdrop-->\r\n  @if (fullscreen() === true) {\r\n  <div class=\"geocoder-backdrop\"></div>\r\n  }\r\n  }\r\n</div>", styles: ["*:focus{outline:0}::placeholder{color:#797979}.geocoder-container{position:relative;width:100%;height:100%;max-width:100%;overscroll-behavior-y:none;line-height:19px;font-size:13px;color:#444}.geocoder-container--fullscreen{position:fixed;top:0;right:0;left:0;height:100vh;height:100dvh}.geocoder-search{position:relative;display:flex;align-items:center;width:100%;z-index:1;background:#fff;box-sizing:border-box;border:1px solid #eee}.geocoder-search__input{flex:1 1 auto;margin:0;padding:14px 15px;max-width:calc(100% - 70px);overflow:hidden;text-overflow:ellipsis;border-radius:15px;border:none}button{display:flex;align-items:center;padding:0 15px;cursor:pointer;background:#fff;border:none}button.close{position:absolute;right:0}button.mic{padding:0 8px 0 0}button.back{padding-right:0}svg{width:18px;height:auto;color:#797979}button.back svg{width:21px}button.mic svg{width:17px}button.close svg{width:15px}button:hover svg{color:#008cba}button.mic--active svg{animation:pulse 1s infinite}@keyframes pulse{0%{color:#797979}50%{color:#3498db}to{color:#797979}}.geocoder-suggestions{position:relative;width:100%;z-index:2;max-height:calc(100% - 49px);overflow-y:auto;overscroll-behavior-y:none;border:1px solid #eee;border-width:0 1px 1px;background:#fff}.geocoder-suggestions__list{margin:0;padding:0;list-style-type:none}.geocoder-suggestion{display:flex;gap:5px;align-items:center;margin:0;padding:12px 15px;border-bottom:1px solid #eee;cursor:pointer}.geocoder-suggestion:last-of-type{border-bottom:none}.geocoder-suggestion:hover,.geocoder-suggestion--focus{background-color:#f7f7f7}.geocoder-suggestion__content{margin-right:10px}.geocoder-suggestion__content__subtitle{color:#838383}.geocoder-suggestion__type{margin:0 0 0 auto;font-size:11px;font-weight:700;text-transform:uppercase;color:#bfbfbf}.geocoder-noresults{position:relative;width:100%;padding:18px 15px;z-index:1;background:#fff;border:1px solid #eee;border-width:0 1px 1px;box-sizing:border-box}.geocoder-backdrop{position:fixed;inset:0;height:100%;width:100%;z-index:0;background:#f5f5f5}.borderradius .geocoder-search,.borderradius .geocoder-search__input{border-radius:0 0 15px 15px}@media (min-width: 787px){.borderradius .geocoder-search,.borderradius .geocoder-search__input{border-radius:15px}}.borderradius button,.borderradius .geocoder-suggestions,.borderradius .geocoder-noresults{border-radius:15px}.boxshadow .geocoder-search,.boxshadow .geocoder-suggestions,.boxshadow .geocoder-noresults{box-shadow:0 2px 4px #0003,0 -1px #00000005;border:none}\n"] }]
        }], ctorParameters: () => [{ type: GeocoderService }, { type: GeocoderHistoryService }], propDecorators: { hostGeocoderClass: [{
                type: HostBinding,
                args: ['class.geocoder--selected']
            }], clickout: [{
                type: HostListener,
                args: ['document:click', ['$event']]
            }] } });

class GeocoderModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: GeocoderModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.0.3", ngImport: i0, type: GeocoderModule, declarations: [GeocoderComponent], imports: [ReactiveFormsModule], exports: [GeocoderComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: GeocoderModule, providers: [
            provideHttpClient(withFetch()),
            provideExperimentalZonelessChangeDetection(),
        ], imports: [ReactiveFormsModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: GeocoderModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [GeocoderComponent],
                    exports: [GeocoderComponent],
                    imports: [
                        ReactiveFormsModule
                    ],
                    providers: [
                        provideHttpClient(withFetch()),
                        provideExperimentalZonelessChangeDetection(),
                    ]
                }]
        }] });

/*
 * Public API Surface of angular-geocoder
 */

/**
 * Generated bundle index. Do not edit.
 */

export { GeocoderComponent, GeocoderModule, GeocoderService };
//# sourceMappingURL=angular-geocoder.mjs.map
